
0.4.14 (2017-05-19)
####################

Changes since 0.4.13 (2016-12-12).

New Features
$$$$$$$$$$$$$

* Closed `#439 <https://github.com/biocommons/hgvs/issues/439/>`_: Add method to explicitly close database connections [`BROKEN: 5a876fd2d1ec <https://github.com/biocommons/hgvs/commit/5a876fd2d1ec>`_]
